write_sensitivity_mtx_with_options

Function write_sensitivity_mtx_with_options 

pub fn write_sensitivity_mtx_with_options(
    case: &IndexedNetwork<'_>,
    options: &SensitivityOptions,
    ptdf_path: impl AsRef<Path>,
    lodf_path: impl AsRef<Path>,
) -> Result<SensitivityMetadata>
Write PTDF and LODF Matrix Market files from the option based sensitivity path and return the metadata for the same entries. The iterative solver path streams retained coordinates through temp files, so it does not keep the full sparse output in memory.