pub fn emit_sensitivity_mtx_with_options(
case: &IndexedNetwork<'_>,
options: &SensitivityOptions,
ptdf_path: impl AsRef<Path>,
lodf_path: impl AsRef<Path>,
) -> Result<SensitivityMetadata>Expand description
Emit PTDF and LODF Matrix Market files from the option based sensitivity path and return the metadata for the same entries. The sparse solver path streams retained coordinates through temp files, so it does not keep the full sparse output in memory.